/*
Copyright 2021 The OpenEBS Authors

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1alpha1

import (
	"context"
	"time"

	v1alpha1 "github.com/openebs/lvm-localpv/pkg/apis/openebs.io/lvm/v1alpha1"
	scheme "github.com/openebs/lvm-localpv/pkg/generated/clientset/internalclientset/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// LVMNodesGetter has a method to return a LVMNodeInterface.
// A group's client should implement this interface.
type LVMNodesGetter interface {
	LVMNodes(namespace string) LVMNodeInterface
}

// LVMNodeInterface has methods to work with LVMNode resources.
type LVMNodeInterface interface {
	Create(ctx context.Context, lVMNode *v1alpha1.LVMNode, opts v1.CreateOptions) (*v1alpha1.LVMNode, error)
	Update(ctx context.Context, lVMNode *v1alpha1.LVMNode, opts v1.UpdateOptions) (*v1alpha1.LVMNode, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.LVMNode, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.LVMNodeList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.LVMNode, err error)
	LVMNodeExpansion
}

// lVMNodes implements LVMNodeInterface
type lVMNodes struct {
	client rest.Interface
	ns     string
}

// newLVMNodes returns a LVMNodes
func newLVMNodes(c *LocalV1alpha1Client, namespace string) *lVMNodes {
	return &lVMNodes{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the lVMNode, and returns the corresponding lVMNode object, and an error if there is any.
func (c *lVMNodes) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1alpha1.LVMNode, err error) {
	result = &v1alpha1.LVMNode{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("lvmnodes").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of LVMNodes that match those selectors.
func (c *lVMNodes) List(ctx context.Context, opts v1.ListOptions) (result *v1alpha1.LVMNodeList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1alpha1.LVMNodeList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("lvmnodes").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested lVMNodes.
func (c *lVMNodes) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("lvmnodes").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a lVMNode and creates it.  Returns the server's representation of the lVMNode, and an error, if there is any.
func (c *lVMNodes) Create(ctx context.Context, lVMNode *v1alpha1.LVMNode, opts v1.CreateOptions) (result *v1alpha1.LVMNode, err error) {
	result = &v1alpha1.LVMNode{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("lvmnodes").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(lVMNode).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a lVMNode and updates it. Returns the server's representation of the lVMNode, and an error, if there is any.
func (c *lVMNodes) Update(ctx context.Context, lVMNode *v1alpha1.LVMNode, opts v1.UpdateOptions) (result *v1alpha1.LVMNode, err error) {
	result = &v1alpha1.LVMNode{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("lvmnodes").
		Name(lVMNode.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(lVMNode).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the lVMNode and deletes it. Returns an error if one occurs.
func (c *lVMNodes) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("lvmnodes").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *lVMNodes) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("lvmnodes").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched lVMNode.
func (c *lVMNodes) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.LVMNode, err error) {
	result = &v1alpha1.LVMNode{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("lvmnodes").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
